/*
**  CXSC is a C++ library for eXtended Scientific Computing
**
**  Copyright (C) 1990-2000 Institut fuer Angewandte Mathematik,
**                          Universitaet Karlsruhe, Germany
**            (C) 2000-2001 Wiss. Rechnen/Softwaretechnologie
**                          Universitaet Wuppertal, Germany   
**
**  This library is free software; you can redistribute it and/or
**  modify it under the terms of the GNU Library General Public
**  License as published by the Free Software Foundation; either
**  version 2 of the License, or (at your option) any later version.
**
**  This library is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
**  Library General Public License for more details.
**
**  You should have received a copy of the GNU Library General Public
**  License along with this library; if not, write to the Free
**  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

/* CVS $Id: lx_cmath.hpp,v 1.4 2002/12/03 19:11:01 cxsc Exp $ */

#ifndef lx_cmath_hpp_included
#define lx_cmath_hpp_included

#include "lx_cimath.hpp"

namespace cxsc {
	
//! Calculates \f$ \sqr(z) \f$
inline lx_complex sqr (const lx_complex&) throw();
//! Calculates \f$ \sqrt{z} \f$
lx_complex sqrt(const lx_complex&) throw();
//! Calculates \f$ \sqrt[n]{z} \f$
lx_complex sqrt(const lx_complex& ,int) throw();
//! Calculates \f$ \exp(z) \f$
lx_complex exp(const lx_complex&) throw();
//! Calculates \f$ 2^z \f$
lx_complex exp2(const lx_complex&) throw();
//! Calculates \f$ 10^z \f$
lx_complex exp10(const lx_complex&) throw();
//! Calculates \f$ \sin(z) \f$
lx_complex sin(const lx_complex&) throw();
//! Calculates \f$ \cos(z) \f$
lx_complex cos(const lx_complex&) throw();
//! Calculates \f$ \tan(z) \f$
lx_complex tan(const lx_complex&) throw();
//! Calculates \f$ \cot(z) \f$
lx_complex cot(const lx_complex&) throw();
//! Calculates \f$ \arcsin(z) \f$
lx_complex asin(const lx_complex&) throw();
//! Calculates \f$ \arccos(z) \f$
lx_complex acos(const lx_complex&) throw();
//! Calculates \f$ \arctan(z) \f$
lx_complex atan(const lx_complex&) throw();
//! Calculates \f$ \mbox{arccot}(z) \f$
lx_complex acot(const lx_complex&) throw();
//! Calculates \f$ \sinh(z) \f$
lx_complex sinh(const lx_complex&) throw();
//! Calculates \f$ \cosh(z) \f$
lx_complex cosh(const lx_complex&) throw();
//! Calculates \f$ \tanh(z) \f$
lx_complex tanh(const lx_complex&) throw();
//! Calculates \f$ \coth(z) \f$
lx_complex coth(const lx_complex&) throw();
//! Calculates \f$ \mbox{arcsinh}(z) \f$
lx_complex asinh(const lx_complex&) throw();
//! Calculates \f$ \mbox{arccosh}(z) \f$
lx_complex acosh(const lx_complex&) throw();
//! Calculates \f$ \mbox{arctanh}(z) \f$
lx_complex atanh(const lx_complex&) throw();
//! Calculates \f$ \mbox{arccoth}(z) \f$
lx_complex acoth(const lx_complex&) throw();
//! Calculates \f$ \sqrt{z} \f$ and returns all possible solutions
std::list<lx_complex>sqrt_all(const lx_complex&);
//! Calculates \f$ \mbox{arg}(z) \f$
lx_real arg(const lx_complex&) throw();
//! Calculates \f$ \mbox{arg}(z) \f$
lx_real Arg(const lx_complex&) throw();
//! Calculates \f$ \sqrt[n]{z} \f$ and returns all possible solutions
std::list<lx_complex>sqrt_all(const lx_complex&, int);
//! Calculates \f$ \ln(z) \f$
lx_complex ln(const lx_complex&) throw();
//! Calculates \f$ \mbox{log2}(z) \f$
lx_complex log2(const lx_complex&) throw();
//! Calculates \f$ \mbox{log10}(z) \f$
lx_complex log10(const lx_complex&) throw();
//! Calculates \f$ z^n \f$
lx_complex power_fast(const lx_complex&, const real&) throw();
//! Calculates \f$ z^n \f$
lx_complex power(const lx_complex&, const real&) throw();
//! Calculates \f$ z^y \f$
lx_complex pow(const lx_complex&, const lx_real&) throw();
//! Calculates \f$ z_1^{z_2} \f$
lx_complex pow(const lx_complex&, const lx_complex&) throw();

//! Calculates \f$ \mbox{sqrt}(1+[z]^2) \f$
lx_complex sqrt1px2(const lx_complex&) throw();
//! Calculates \f$ \mbox{sqrt}(1-[z]^2) \f$	 
lx_complex sqrt1mx2(const lx_complex&) throw();
//! Calculates \f$ \mbox{sqrt}([z]^2-1) \f$
lx_complex sqrtx2m1(const lx_complex&) throw();
//! Calculates \f$ \mbox{sqrt}([z]+1)-1 \f$
lx_complex sqrtp1m1(const lx_complex&) throw();
//! Calculates \f$ \mbox{exp}([z])-1 \f$
lx_complex expm1(const lx_complex&) throw();
//! Calculates \f$ \mbox{ln}(1+[z]) \f$	 
lx_complex lnp1(const lx_complex&) throw();

} // namespace cxsc 

#include "lx_cmath.inl"
#endif







