/*-------------------------------------------------------------------------
  Sample program lxitayl_ex2.cpp for extended staggered Taylor arithmetic.
  Calculating guaranteed inclusions of the first two derivatives of the
  function  f = atan(x^2/(1+x^2)) in interval staggered arithmetic.
--------------------------------------------------------------------------*/

#include "lxitaylor.hpp"   // Header file for class lx_itaylor
#include "lx_interval.hpp" // Extended interval staggered arithmetic
#include <iostream>        // Input, output

using namespace std;
using namespace taylor;
using namespace cxsc;

lx_itaylor f1(const lx_itaylor& x)
{
    lx_itaylor w;
    lx_real S( abs( Sup(get_j_derivative(x,0)) ) );
    if (S<1) 
	 {
		w = sqr(x);
		atan( w/(1+w) );
    }
    else 
		w = atan(1/(1+sqr(1/x)));  // to avoid overflow
    return w;
}

int main()
{
    stagprec = 3;  // Provides a precision of about 3*16=48 
                   // decimal digits.
    int p = 2;     // Taylor expansion of order p
    lx_interval lxi;
//    lxi = lx_interval(-9007199254737871.0,l_interval(1));
    lxi = lx_interval(+2251799813684420.0,l_interval(1));
    lx_itaylor x(p,lxi);  // Constructor call for  
                          // independentvariable x of order p=2;
    lx_itaylor f,g,h;     // Default constructor call;

    f = f1(x); // After assignment: f is Taylor object of order p.
    cout << SetDotPrecision(16*stagprec,16*stagprec) << Scientific
         << "Derivatives of function f1(x):" << endl;
    cout << "1. derivative: " << get_j_derivative(f,1)  << endl;
    cout << "2. derivative: " << get_j_derivative(f,2)  << endl;

    cout << "Derivatives of function g(x):" << endl;
    g = sqr(x); g = atan(g/(1+g)); // suitable for |(x)_0| < 1;
    cout << "1. derivative: " << get_j_derivative(g,1)  << endl;
    cout << "2. derivative: " << get_j_derivative(g,2)  << endl;

    cout << "Derivatives of function h(x):" << endl;
    h = atan(1/(1+sqr(1/x))); // suitable for |(x)_0| >= 1;
    cout << "1. derivative: " << get_j_derivative(h,1)  << endl;
    cout << "2. derivative: " << get_j_derivative(h,2)  << endl;
}

